package tech.riemann.ims.entity.material;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.media.Schema.RequiredMode;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.experimental.Accessors;
import lombok.experimental.FieldNameConstants;
import lombok.experimental.SuperBuilder;
import org.nutz.dao.entity.annotation.ColDefine;
import org.nutz.dao.entity.annotation.Column;
import org.nutz.dao.entity.annotation.Comment;
import org.nutz.dao.entity.annotation.Table;
import tech.riemann.ims.entity.IdBaseEntity;
import tech.riemann.ims.enums.StockStatusEnum;

import java.io.Serial;

/**
 * 物料明细数据表
 *
 * @author mayong)
 *
 * @since 2024-12-06 10:32:29
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@FieldNameConstants
@EqualsAndHashCode(callSuper = true)
@Accessors(chain = true)
@TableName("t_material_stock_detail")
@Table("t_material_stock_detail")
@Comment("物料明细数据表")
@Schema(name = "MaterialStockDetail", description = "物料明细数据表")
public class MaterialStockDetail extends IdBaseEntity{

    @Serial
    private static final long serialVersionUID = 1L;

    @Schema(description = "物料ID", requiredMode = RequiredMode.NOT_REQUIRED)
    @TableField("msd_material_id")
    @Column("msd_material_id")
    @Comment("物料ID")
    @ColDefine(notNull = false)
    private Long materialId;

    @Schema(description = "条码", requiredMode = RequiredMode.NOT_REQUIRED)
    @TableField("msd_barcode")
    @Column("msd_barcode")
    @Comment("条码")
    @ColDefine(notNull = false, width = 128, precision = 0)
    private String barcode;

    @Schema(description = "入库申请单", requiredMode = RequiredMode.NOT_REQUIRED)
    @TableField("msd_apply_id")
    @Column("msd_apply_id")
    @Comment("入库申请单")
    @ColDefine(notNull = false)
    private Long applyId;

    @Schema(description = "状态", requiredMode = RequiredMode.NOT_REQUIRED)
    @TableField("msd_status")
    @Column("msd_status")
    @Comment("状态")
    @ColDefine(notNull = false, width = 128, precision = 0)
    private StockStatusEnum status;


}