package tech.riemann.ims.service.acl.impl;

import java.util.List;
import java.util.stream.Collectors;

import org.nutz.dao.Dao;
import org.springframework.stereotype.Service;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;

import lombok.RequiredArgsConstructor;
import tech.riemann.ims.dto.response.PermissionInfo;
import tech.riemann.ims.entity.acl.Permission;
import tech.riemann.ims.entity.acl.Role;
import tech.riemann.ims.entity.acl.RolePermission;
import tech.riemann.ims.mapper.acl.RoleMapper;
import tech.riemann.ims.mapper.acl.RolePermissionMapper;
import tech.riemann.ims.service.acl.IRoleService;

/**
 * <p>
 * 角色 服务实现类
 * </p>
 *
 * @author Kerbores(kerbores@gmail.com)
 *
 * @since 2024-09-10 18:07:15
 */
@Service
@RequiredArgsConstructor
public class RoleServiceImpl extends ServiceImpl<RoleMapper, Role> implements IRoleService {

    private final Dao dao;
    private final RolePermissionMapper rolePermissionMapper;

    /**
     * @return
     * @see org.nutz.spring.boot.service.ExtService#dao()
     */
    @Override
    public Dao dao() {
        return dao;
    }

    /**
     * @return
     * @see org.nutz.spring.boot.service.interfaces.EntityService#getEntityType()
     */
    @Override
    public Class<Role> getEntityType() {
        return Role.class;
    }

    /**
     * @param key
     * @return
     * @see tech.riemann.laacam.service.acl.IRoleService#permissionsByRoleKey(java.lang.String)
     */
    @Override
    public List<Permission> permissionsByRoleKey(String key) {
        return permissionInfosByKey(key)
                                        .stream()
                                        .filter(PermissionInfo::isSelected)
                                        .collect(Collectors.toList());
    }

    /**
     * @param key
     * @return
     * @see tech.riemann.laacam.service.acl.IRoleService#permissionInfosByKey(java.lang.String)
     */
    @Override
    public List<PermissionInfo> permissionInfosByKey(String key) {
        return getBaseMapper().permissionInfosByKey(key);
    }

    /**
     * @param key
     * @param permissions
     * @return
     * @see tech.riemann.laacam.service.acl.IRoleService#grant(java.lang.String,
     *      java.util.List)
     */
    @Override
    public boolean grant(String key, List<String> permissions) {
        rolePermissionMapper.delete(Wrappers.<RolePermission> lambdaQuery().eq(RolePermission::getRoleKey, key));
        rolePermissionMapper.insert(permissions.stream()
                                               .map(p -> RolePermission.builder().roleKey(key).permissionKeyPath(p).build())
                                               .collect(Collectors.toList()));
        return true;
    }
}
